@@ -54,9 +54,13 @@ class ShowFrame():
             textvariable = self.ct_stringvar )
 
         # shoot
-        self.pr_sv = tk.StringVar( frame, _('Recognize'))
+        self.pp_sv = tk.StringVar( frame, _('Pause'))
         self.pp_btn = tk.Button( self.frame, \
-            textvariable = self.pr_sv )
+            textvariable = self.pp_sv )
+
+        self.rec_sv = tk.StringVar( frame, _('Recognize'))
+        self.rec_btn = tk.Button( self.frame, \
+            textvariable = self.rec_sv )
 
         self.pick_sv = tk.StringVar( frame, _('Pick'))
         self.pick_btn = tk.Button( self.frame, \
@@ -73,8 +77,10 @@ class ShowFrame():
         self.showf_optionmenu.grid( column = 2, row = 4 , sticky = W)
         # self.ct_label.grid( column = 3, row = 4, sticky = E )
         # self.ct_entry.grid( column = 4, row = 4, sticky = W )
-        self.pp_btn.grid( column = 5, row = 4)
-        self.pick_btn.grid( column = 6, row = 4 )        
+        self.pp_btn.grid( column = 3, row = 4)
+        self.rec_btn.grid( column = 4, row = 4)
+        
+        self.pick_btn.grid( column = 5, row = 4 )        
         # place frame
         self.frame.grid( column = 0, row = 0 )             
 
@@ -83,11 +89,14 @@ class InfoFrame():
         self.frame = frame
         self.face_show_frame = tk.Frame( self.frame )
         self.info_enter_frame = tk.Frame( self.frame )
-        self.curf_label = tk.Label( self.face_show_frame )
-        self.opt_frame =  tk.Frame( self.frame )
-        self.prevf_btn = tk.Button( self.opt_frame, text = _('prev_symb'))
-        self.num_label = tk.Label( self.opt_frame, text = _('*/*') )
-        self.nextf_btn = tk.Button( self.opt_frame, text = _('next_symb'))
+
+        self.faces_frame = tk.Frame( self.frame )
+
+        # self.curf_label = tk.Label( self.face_show_frame )
+        # self.opt_frame =  tk.Frame( self.frame )
+        # self.prevf_btn = tk.Button( self.opt_frame, text = _('prev_symb'))
+        # self.num_label = tk.Label( self.opt_frame, text = _('*/*') )
+        # self.nextf_btn = tk.Button( self.opt_frame, text = _('next_symb'))
         self.ft_sb = tk.Scrollbar(self.info_enter_frame, orient=VERTICAL)
         self.faces_text = Text( self.info_enter_frame,  \
         yscrollcommand = self.ft_sb.set)  
@@ -97,17 +106,18 @@ class InfoFrame():
         self.save_btn = tk.Button( self.frame, text = _("Save") )
         self.ft_sb.config(command = self.faces_text.yview)      
     def place( self ):
-        self.curf_label.pack(side = LEFT)
-        self.prevf_btn.pack(side = LEFT)
-        self.num_label.pack(side=LEFT)
-        self.nextf_btn.pack(side = LEFT)
+        # self.curf_label.pack(side = LEFT)
+        # self.prevf_btn.pack(side = LEFT)
+        # self.num_label.pack(side=LEFT)
+        # self.nextf_btn.pack(side = LEFT)
         self.faces_text.pack(side=tk.LEFT,fill=tk.Y)
         self.ft_sb.pack(side=tk.RIGHT,fill=tk.Y)
-        self.face_show_frame.grid( column = 0, row = 0, columnspan = 5)
-        self.opt_frame.grid( column = 0, row = 1, columnspan = 5)
-        self.info_enter_frame.grid( column = 0, row = 2, columnspan = 5)
-        self.faces_text_tip_label.grid(column = 0, row = 3,  columnspan = 5)
-        self.save_btn.grid( column = 2, row = 4 )
+        self.faces_frame.grid( column = 0 , row = 0, columnspan = 5 )
+        # self.face_show_frame.grid( column = 0, row = 1, columnspan = 5)
+        # self.opt_frame.grid( column = 0, row = 2, columnspan = 5)
+        self.info_enter_frame.grid( column = 0, row = 3, columnspan = 5)
+        self.faces_text_tip_label.grid(column = 0, row = 4,  columnspan = 5)
+        self.save_btn.grid( column = 2, row = 5 )
         self.frame.grid( column = 1, row = 0 )
         pass
 
