@@ -7,7 +7,7 @@ from pathlib import Path
 import getopt
 import sys
 
-version =  "0.2.33"
+version =  "0.2.34"
 args = \
     getopt.getopt( sys.argv[1:], '' )[1]
 test_args = \
@@ -16,17 +16,19 @@ debug =  \
     len( set(args)&set(test_args) ) > 0
 project_path = \
     os.path.abspath( os.path.dirname(  __file__  ) )
-usr_home = \
-    os.path.join( project_path, '_home' ) if debug \
-    else os.path.expanduser('~')
+_usr_home =  \
+    os.path.expanduser('~')
+_test_user_home =\
+    os.path.join( project_path, '.home' ) 
+usr_home = _test_user_home if debug else _usr_home
 base_dir = \
     os.path.join( usr_home , '.funing')
 locale_path = \
     os.path.join( project_path, 'locale') 
-config_path = \
-    os.path.join( base_dir , 'config.yml') 
 _config_path = \
-    config_path
+    os.path.join( base_dir , 'config.yml') 
+config_path = \
+    _config_path
 if not os.path.exists( config_path ): config_path = \
     os.path.join( project_path , 'config.example.yml') 
 config_yml = \
@@ -55,4 +57,5 @@ prev_version = \
     config_yml.get('version', version )
 initialized  = \
     config_yml.get('initialized', False) and (version == prev_version)
-    
\ No newline at end of file
+backup_dir_path = \
+    os.path.join( base_dir, '.cp' )
\ No newline at end of file
